@@ -6,13 +6,12 @@ import pytest
 from typer.testing import CliRunner
 
 from every_python.main import (
+    _ensure_repo,
+    _resolve_ref,
     app,
-    build_python,
-    ensure_repo,
-    resolve_ref,
 )
-from every_python.output import QuietOutputHandler, set_output
-from every_python.runner import CommandResult, CommandRunner, set_runner
+from every_python.output import set_output
+from every_python.runner import set_runner
 
 runner = CliRunner()
 
@@ -36,7 +35,7 @@ class TestEnsureRepo:
 
         with patch("every_python.main.REPO_DIR", repo_dir):
             mock_run.return_value = Mock(returncode=0, stdout="", stderr="")
-            ensure_repo()
+            _ensure_repo()
 
             # Should have called git clone
             assert any(
@@ -52,9 +51,8 @@ class TestEnsureRepo:
             patch("every_python.main.REPO_DIR", repo_dir),
             patch("subprocess.run") as mock_run,
         ):
-            ensure_repo()
+            _ensure_repo()
 
-            # Should not have called git clone
             mock_run.assert_not_called()
 
 
@@ -71,7 +69,7 @@ class TestResolveRef:
             mock_run.return_value = Mock(
                 returncode=0, stdout="abc123def456\n", stderr=""
             )
-            commit = resolve_ref("main")
+            commit = _resolve_ref("main")
 
             assert commit == "abc123def456"
             assert "rev-parse" in str(mock_run.call_args)
@@ -86,7 +84,7 @@ class TestResolveRef:
             mock_run.return_value = Mock(
                 returncode=0, stdout="def456abc123\n", stderr=""
             )
-            commit = resolve_ref("v3.13.0")
+            commit = _resolve_ref("v3.13.0")
 
             assert commit == "def456abc123"
 
@@ -103,161 +101,14 @@ class TestResolveRef:
             from click.exceptions import Exit
 
             with pytest.raises(Exit):
-                resolve_ref("invalid-ref")
-
-
-class TestBuildPython:
-    """Test Python building logic."""
-
-    def test_build_without_jit(self, tmp_path: Path):
-        """Test building Python without JIT."""
-
-        # Create mock runner
-        mock_runner = Mock(spec=CommandRunner)
-        mock_runner.run_git.return_value = CommandResult(
-            returncode=0, stdout="", stderr=""
-        )
-        mock_runner.run.return_value = CommandResult(returncode=0, stdout="", stderr="")
-
-        # Set up dependency injection
-        set_runner(mock_runner)
-        set_output(QuietOutputHandler())
-
-        repo_dir = tmp_path / "cpython"
-        repo_dir.mkdir(parents=True)
-        builds_dir = tmp_path / "builds"
-
-        with (
-            patch("every_python.main.REPO_DIR", repo_dir),
-            patch("every_python.main.BUILDS_DIR", builds_dir),
-        ):
-            build_dir = build_python("abc123d", enable_jit=False)
-
-            # Should create non-JIT build directory
-            assert build_dir.name == "abc123d"
-            assert not build_dir.name.endswith("-jit")
-
-    def test_build_with_jit_available(self, tmp_path: Path):
-        """Test building Python with JIT when LLVM is available."""
-        # Create mock runner
-        mock_runner = Mock(spec=CommandRunner)
-        mock_runner.run_git.return_value = CommandResult(
-            returncode=0, stdout="", stderr=""
-        )
-        mock_runner.run.return_value = CommandResult(returncode=0, stdout="", stderr="")
-
-        # Set up dependency injection
-        set_runner(mock_runner)
-        set_output(QuietOutputHandler())
-
-        repo_dir = tmp_path / "cpython"
-        repo_dir.mkdir(parents=True)
-        builds_dir = tmp_path / "builds"
-
-        with (
-            patch("every_python.main.REPO_DIR", repo_dir),
-            patch("every_python.main.BUILDS_DIR", builds_dir),
-            patch("every_python.main.get_llvm_version_for_commit", return_value="20"),
-            patch("every_python.main.check_llvm_available", return_value=True),
-        ):
-            build_dir = build_python("abc123d", enable_jit=True)
-
-            # Should create JIT build directory
-            assert build_dir.name == "abc123d-jit"
-
-            # Should pass --enable-experimental-jit to configure
-            configure_calls = [
-                call_args
-                for call_args in mock_runner.run.call_args_list
-                if "./configure" in str(call_args)
-            ]
-            assert len(configure_calls) > 0
-            assert "--enable-experimental-jit" in str(configure_calls[0])
-
-    def test_build_with_jit_llvm_missing(self, tmp_path: Path):
-        """Test building with JIT when LLVM is missing falls back to non-JIT."""
-        # Create mock runner
-        mock_runner = Mock(spec=CommandRunner)
-        mock_runner.run_git.return_value = CommandResult(
-            returncode=0, stdout="", stderr=""
-        )
-        mock_runner.run.return_value = CommandResult(returncode=0, stdout="", stderr="")
-
-        # Set up dependency injection
-        set_runner(mock_runner)
-        set_output(QuietOutputHandler())
-
-        repo_dir = tmp_path / "cpython"
-        repo_dir.mkdir(parents=True)
-        builds_dir = tmp_path / "builds"
-
-        with (
-            patch("every_python.main.REPO_DIR", repo_dir),
-            patch("every_python.main.BUILDS_DIR", builds_dir),
-            patch("every_python.main.get_llvm_version_for_commit", return_value="20"),
-            patch("every_python.main.check_llvm_available", return_value=False),
-            patch("typer.confirm", return_value=True),
-        ):
-            build_dir = build_python("abc123d", enable_jit=True)
-
-            # Should fall back to non-JIT build
-            assert build_dir.name == "abc123d"
-            assert not build_dir.name.endswith("-jit")
-
-    def test_build_with_jit_not_available_in_commit(self, tmp_path: Path):
-        """Test building with JIT when JIT not available in commit."""
-        # Create mock runner
-        mock_runner = Mock(spec=CommandRunner)
-        mock_runner.run_git.return_value = CommandResult(
-            returncode=0, stdout="", stderr=""
-        )
-        mock_runner.run.return_value = CommandResult(returncode=0, stdout="", stderr="")
-
-        # Set up dependency injection
-        set_runner(mock_runner)
-        set_output(QuietOutputHandler())
-
-        repo_dir = tmp_path / "cpython"
-        repo_dir.mkdir(parents=True)
-        builds_dir = tmp_path / "builds"
-
-        with (
-            patch("every_python.main.REPO_DIR", repo_dir),
-            patch("every_python.main.BUILDS_DIR", builds_dir),
-            patch("every_python.main.get_llvm_version_for_commit", return_value=None),
-            patch("typer.confirm", return_value=True),
-        ):
-            build_dir = build_python("abc123d", enable_jit=True)
-
-            # Should fall back to non-JIT build
-            assert build_dir.name == "abc123d"
-
-    def test_build_already_exists(self, tmp_path: Path):
-        """Test that existing build is reused."""
-        repo_dir = tmp_path / "cpython"
-        repo_dir.mkdir(parents=True)
-        builds_dir = tmp_path / "builds"
-        builds_dir.mkdir(parents=True)
-
-        # Create existing build
-        existing_build = builds_dir / "abc123d"
-        existing_build.mkdir()
-
-        with (
-            patch("every_python.main.REPO_DIR", repo_dir),
-            patch("every_python.main.BUILDS_DIR", builds_dir),
-        ):
-            build_dir = build_python("abc123d", enable_jit=False)
-
-            # Should return existing build without running any configure/make
-            assert build_dir == existing_build
+                _resolve_ref("invalid-ref")
 
 
 class TestInstallCommand:
     """Test the install command."""
 
     @patch("every_python.main.build_python")
-    @patch("every_python.main.resolve_ref")
+    @patch("every_python.main._resolve_ref")
     def test_install_main(self, mock_resolve: Mock, mock_build: Mock, tmp_path: Path):
         """Test installing main branch."""
         mock_resolve.return_value = "abc123def456"
@@ -273,7 +124,7 @@ class TestInstallCommand:
         )
 
     @patch("every_python.main.build_python")
-    @patch("every_python.main.resolve_ref")
+    @patch("every_python.main._resolve_ref")
     def test_install_with_jit(
         self, mock_resolve: Mock, mock_build: Mock, tmp_path: Path
     ):
@@ -289,7 +140,7 @@ class TestInstallCommand:
         )
 
     @patch("every_python.main.build_python")
-    @patch("every_python.main.resolve_ref")
+    @patch("every_python.main._resolve_ref")
     def test_install_verbose(
         self, mock_resolve: Mock, mock_build: Mock, tmp_path: Path
     ):
@@ -309,11 +160,13 @@ class TestRunCommand:
     """Test the run command."""
 
     @patch("os.execv")
-    @patch("every_python.main.resolve_ref")
+    @patch("every_python.main._resolve_ref")
+    @patch("platform.system")
     def test_run_existing_build(
-        self, mock_resolve: Mock, mock_execv: Mock, tmp_path: Path
+        self, mock_platform: Mock, mock_resolve: Mock, mock_execv: Mock, tmp_path: Path
     ):
         """Test running with existing build."""
+        mock_platform.return_value = "Linux"  # Force Unix behavior
         mock_resolve.return_value = "abc123def456"
 
         builds_dir = tmp_path / "builds"
@@ -331,7 +184,7 @@ class TestRunCommand:
             assert "python3" in args[0]
 
     @patch("every_python.main.build_python")
-    @patch("every_python.main.resolve_ref")
+    @patch("every_python.main._resolve_ref")
     @patch("os.execv")
     def test_run_triggers_build(
         self, mock_execv: Mock, mock_resolve: Mock, mock_build: Mock, tmp_path: Path
@@ -401,7 +254,12 @@ class TestListBuildsCommand:
             if "--version" in cmd:
                 return Mock(returncode=0, stdout="Python 3.14.0a1+", stderr="")
             elif "git" in cmd and "log" in cmd:
-                return Mock(returncode=0, stdout="1234567890|Test commit", stderr="")
+                # Format: hash|timestamp|subject (matching --format=%H|%at|%s)
+                return Mock(
+                    returncode=0,
+                    stdout="abc123d|1234567890|Test commit\ndef456a|1234567891|Test commit JIT",
+                    stderr="",
+                )
             return Mock(returncode=0, stdout="", stderr="")
 
         mock_run.side_effect = mock_run_side_effect
@@ -425,14 +283,14 @@ class TestCleanCommand:
         builds_dir = tmp_path / "builds"
         builds_dir.mkdir(parents=True)
 
-        # Create builds - use the full commit hash that resolve_ref will return
+        # Create builds - use the full commit hash that _resolve_ref will return
         (builds_dir / "abc123def456").mkdir()
         (builds_dir / "abc123def456-jit").mkdir()
         (builds_dir / "def456a").mkdir()
 
         with (
             patch("every_python.main.BUILDS_DIR", builds_dir),
-            patch("every_python.main.resolve_ref", return_value="abc123def456"),
+            patch("every_python.main._resolve_ref", return_value="abc123def456"),
         ):
             result = runner.invoke(app, ["clean", "main"])
 
@@ -459,7 +317,7 @@ class TestBisectCommand:
     """Test the bisect command."""
 
     @patch("subprocess.run")
-    @patch("every_python.main.resolve_ref")
+    @patch("every_python.main._resolve_ref")
     @patch("every_python.main.build_python")
     def test_bisect_basic(
         self, mock_build: Mock, mock_resolve: Mock, mock_run: Mock, tmp_path: Path
@@ -471,7 +329,7 @@ class TestBisectCommand:
 
         builds_dir = tmp_path / "builds"
 
-        def resolve_side_effect(ref):
+        def resolve_side_effect(ref: str) -> str:
             if ref == "good-ref":
                 return "abc123d"
             elif ref == "bad-ref":
